# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.general_api_settings import GeneralApiSettings
from ..types.general_attachment_settings import GeneralAttachmentSettings
from ..types.general_repo_settings import GeneralRepoSettings
from ..types.general_ui_settings import GeneralUiSettings
from .raw_client import AsyncRawSettingsClient, RawSettingsClient


class SettingsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSettingsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSettingsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSettingsClient
        """
        return self._raw_client

    def get_general_api_settings(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralApiSettings:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralApiSettings
            GeneralAPISettings

        Examples
        --------
        from pyforgejo import PyforgejoApi

        client = PyforgejoApi(
            api_key="YOUR_API_KEY",
        )
        client.settings.get_general_api_settings()
        """
        response = self._raw_client.get_general_api_settings(
            request_options=request_options
        )
        return response.data

    def get_general_attachment_settings(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralAttachmentSettings:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralAttachmentSettings
            GeneralAttachmentSettings

        Examples
        --------
        from pyforgejo import PyforgejoApi

        client = PyforgejoApi(
            api_key="YOUR_API_KEY",
        )
        client.settings.get_general_attachment_settings()
        """
        response = self._raw_client.get_general_attachment_settings(
            request_options=request_options
        )
        return response.data

    def get_general_repository_settings(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralRepoSettings:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralRepoSettings
            GeneralRepoSettings

        Examples
        --------
        from pyforgejo import PyforgejoApi

        client = PyforgejoApi(
            api_key="YOUR_API_KEY",
        )
        client.settings.get_general_repository_settings()
        """
        response = self._raw_client.get_general_repository_settings(
            request_options=request_options
        )
        return response.data

    def get_general_ui_settings(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralUiSettings:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralUiSettings
            GeneralUISettings

        Examples
        --------
        from pyforgejo import PyforgejoApi

        client = PyforgejoApi(
            api_key="YOUR_API_KEY",
        )
        client.settings.get_general_ui_settings()
        """
        response = self._raw_client.get_general_ui_settings(
            request_options=request_options
        )
        return response.data


class AsyncSettingsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSettingsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSettingsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSettingsClient
        """
        return self._raw_client

    async def get_general_api_settings(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralApiSettings:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralApiSettings
            GeneralAPISettings

        Examples
        --------
        import asyncio

        from pyforgejo import AsyncPyforgejoApi

        client = AsyncPyforgejoApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.settings.get_general_api_settings()


        asyncio.run(main())
        """
        response = await self._raw_client.get_general_api_settings(
            request_options=request_options
        )
        return response.data

    async def get_general_attachment_settings(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralAttachmentSettings:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralAttachmentSettings
            GeneralAttachmentSettings

        Examples
        --------
        import asyncio

        from pyforgejo import AsyncPyforgejoApi

        client = AsyncPyforgejoApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.settings.get_general_attachment_settings()


        asyncio.run(main())
        """
        response = await self._raw_client.get_general_attachment_settings(
            request_options=request_options
        )
        return response.data

    async def get_general_repository_settings(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralRepoSettings:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralRepoSettings
            GeneralRepoSettings

        Examples
        --------
        import asyncio

        from pyforgejo import AsyncPyforgejoApi

        client = AsyncPyforgejoApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.settings.get_general_repository_settings()


        asyncio.run(main())
        """
        response = await self._raw_client.get_general_repository_settings(
            request_options=request_options
        )
        return response.data

    async def get_general_ui_settings(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GeneralUiSettings:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GeneralUiSettings
            GeneralUISettings

        Examples
        --------
        import asyncio

        from pyforgejo import AsyncPyforgejoApi

        client = AsyncPyforgejoApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.settings.get_general_ui_settings()


        asyncio.run(main())
        """
        response = await self._raw_client.get_general_ui_settings(
            request_options=request_options
        )
        return response.data
